@@ -4,12 +4,12 @@ from raumo_data_tools.config_handler import ConfigHandler
 from influxdb_client import InfluxDBClient
 import pandas as pd
 import json
-from datetime import date, timedelta
+from datetime import timedelta
 import numpy as np
 
 class QueryInflux():
-    def __init__(self, config_name):
-        self.config = ConfigHandler(config_name)
+    def __init__(self, config):
+        self.config = config
         self.client = InfluxDBClient(url=self.config.URL, token=self.config.TOKEN, org=self.config.ORG)
 
     def _concat_list_result(self, result):
